schemetools.SchemeMoment
========================

.. inheritance-diagram:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment
   :private-bases:

.. autoclass:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.duration

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.format

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__eq__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__ge__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__gt__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__le__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__lt__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__ne__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__repr__

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.SchemeMoment.__str__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`
